==> accounts_management-0.1.6.gem: config/routes.rb <==
AccountsManagement::Engine.routes.draw do

  namespace :ledgers do
    resources :master_data
    resources :accounts
    resources :ledgers
    resources :ledger_entry_headers
    resources :ledger_entry_header_archives
    resources :ledger_entries
  end

  namespace :documents do
    resources :orders
    resources :invoices
    resources :invoice_styles
    resources :invoice_statuses
    resources :invoice_entry_types
    resources :invoice_entries
    resources :contracts
    resources :contract_statuses
    resources :contract_line_items
  end

  namespace :accounts do
    resources :bank_accounts
    resources :client_accounts
  end

  #get "dashboard/index"
  get '/dashboard(/:section)' => 'dashboard#index'

  #get "accounts_payable/index"
  get '/accounts_payable(/:section)' => 'accounts_payable#index'

  #get "accounts_receiveable/index"
  get '/accounts_receiveable(/:section)' => 'accounts_receiveable#index'

  #get "billing/index"
  get '/billing(/:section)' => 'billing#index'

  #get "currency_management/index"
  get '/currency_management(/:section)' => 'currency_management#index'

  #get "debt_collection/index"
  get '/debt_collection(/:section)' => 'debt_collection#index'

  #get "general_ledger/index"
  get '/general_ledger(/:section)' => 'general_ledger#index'

  #get "inquiries/index"
  get '/inquiries(/:section)' => 'inquiries#index'

  #get "payroll/index"
  get '/payroll(/:section)' => 'payroll#index'

  #get "purchase_orders/index"
  get '/purchase_orders(/:section)' => 'purchase_orders#index'

  #get "purchase_requisitions/index"
  get '/purchase_requisitions(/:section)' => 'purchase_requisitions#index'

  #get "reports/index"
  get '/reports(/:section)' => 'reports#index'

  #get "sales_orders/index"
  get '/sales_orders(/:section)' => 'sales_orders#index'

  # Mount dependent engines if they are not directly mounted by the application (Gemfile or routes.rb)
  # - the assumption is that the application will handle the mount path
  # - we must handle non-deterministic load/mount order of dependent engines
  [:core_models, :asset_management].each do |engine|
    #unless Rails.application.config.eager_load_namespaces.include?("#{engine.capitalize}::Engine".constantize.class)
    #unless Rails.application.routes.named_routes.routes.keys.include?(engine)
    unless Rails.application.routes.named_routes.key?(engine)
      mount "::#{engine.to_s.camelize}::Engine".constantize => "/#{engine.to_s}", :as => engine
    end
  end

  get 'dashboard' => 'dashboard#index'

  get 'health' => 'application#health'

  root :to => 'dashboard#index'
end

==> accounts_management-0.1.7.gem: config/routes.rb <==
AccountsManagement::Engine.routes.draw do
  namespace :ledgers do
    resources :master_data
    resources :accounts
    resources :ledgers
    resources :ledger_entry_headers
    resources :ledger_entry_header_archives
    resources :ledger_entries
  end

  namespace :documents do
    resources :orders
    resources :invoices
    resources :invoice_styles
    resources :invoice_statuses
    resources :invoice_entry_types
    resources :invoice_entries
    resources :contracts
    resources :contract_statuses
    resources :contract_line_items
  end

  namespace :accounts do
    resources :bank_accounts
    resources :client_accounts
  end

  # get "dashboard/index"
  get '/dashboard(/:section)' => 'dashboard#index'

  # get "accounts_payable/index"
  get '/accounts_payable(/:section)' => 'accounts_payable#index'

  # get "accounts_receiveable/index"
  get '/accounts_receiveable(/:section)' => 'accounts_receiveable#index'

  # get "billing/index"
  get '/billing(/:section)' => 'billing#index'

  # get "currency_management/index"
  get '/currency_management(/:section)' => 'currency_management#index'

  # get "debt_collection/index"
  get '/debt_collection(/:section)' => 'debt_collection#index'

  # get "general_ledger/index"
  get '/general_ledger(/:section)' => 'general_ledger#index'

  # get "inquiries/index"
  get '/inquiries(/:section)' => 'inquiries#index'

  # get "payroll/index"
  get '/payroll(/:section)' => 'payroll#index'

  # get "purchase_orders/index"
  get '/purchase_orders(/:section)' => 'purchase_orders#index'

  # get "purchase_requisitions/index"
  get '/purchase_requisitions(/:section)' => 'purchase_requisitions#index'

  # get "reports/index"
  get '/reports(/:section)' => 'reports#index'

  # get "sales_orders/index"
  get '/sales_orders(/:section)' => 'sales_orders#index'

  # Mount dependent engines if they are not directly mounted by the application (Gemfile or routes.rb)
  # - the assumption is that the application will handle the mount path
  # - we must handle non-deterministic load/mount order of dependent engines
  [:core_models, :asset_management].each do |engine|
    # unless Rails.application.config.eager_load_namespaces.include?("#{engine.capitalize}::Engine".constantize.class)
    # unless Rails.application.routes.named_routes.routes.keys.include?(engine)
    unless Rails.application.routes.named_routes.key?(engine)
      mount "::#{engine.to_s.camelize}::Engine".constantize => "/#{engine}", as: engine
    end
  end

  get 'dashboard' => 'dashboard#index'

  root to: 'dashboard#index'
end
